builders/default_builders library

Classes

PasswordField
A specialized text field for password entry with a visibility toggle.
ThemeProvider
Utility to provide a BuildContext globally for showing dialogs and resolve themes.

Properties

defaultBuilders Map<FieldType, FieldBuilder>
The default set of field builders provided by the library.
final

Typedefs

FieldBuilder = Widget Function(DynamicField config, DynamicFormController controller, DynamicFormTheme theme)
Signature for a function that builds a form field widget.