ThemeProvider class
Utility to provide a BuildContext globally for showing dialogs and resolve themes.
Set navigatorKey in your MaterialApp or CupertinoApp to enable this.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- context → BuildContext
-
Retrieves the current BuildContext from the navigatorKey.
no setter
-
The global navigator key used to access the current BuildContext.
getter/setter pair