navigatorKey property
The global navigator key used to access the current BuildContext.
Implementation
static GlobalKey<NavigatorState> navigatorKey = GlobalKey<NavigatorState>();
The global navigator key used to access the current BuildContext.
static GlobalKey<NavigatorState> navigatorKey = GlobalKey<NavigatorState>();