validate method

bool validate()

Triggers the validation of the entire form using the formKey. Returns true if the form is valid, false otherwise.

Implementation

bool validate() => formKey.currentState?.validate() ?? false;