equals property
The list of values that, if matched by the target field, will satisfy the condition.
Implementation
final List<dynamic> equals;
The list of values that, if matched by the target field, will satisfy the condition.
final List<dynamic> equals;