DropdownOption class

Represents an option in a dropdown selection field.

Constructors

Creates a new DropdownOption instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
The human-readable label displayed for the option.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of the option.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this DropdownOption instance to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) DropdownOption
Creates a DropdownOption instance from a JSON map.