decoration property
Custom input decoration to override the default theme or decorationProps.
Implementation
final InputDecoration? decoration;
Custom input decoration to override the default theme or decorationProps.
final InputDecoration? decoration;