registerCustomValidator function
Registers a custom validator function globally under a specific key.
Implementation
void registerCustomValidator(String key, CustomValidator validator) {
_customValidators[key] = validator;
}
Registers a custom validator function globally under a specific key.
void registerCustomValidator(String key, CustomValidator validator) {
_customValidators[key] = validator;
}