DynamicStep class
Represents a single step in a multi-step form (Stepper).
Constructors
-
DynamicStep({required String title, String? subtitle, required List<
DynamicField> fields, bool isActive = true}) -
Creates a new DynamicStep instance.
const
-
DynamicStep.fromJson(Map<
String, dynamic> json) -
Creates a DynamicStep instance from a JSON map.
factory
Properties
-
fields
→ List<
DynamicField> -
The list of fields to display in this step.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Whether this step is active/enabled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → String?
-
Optional subtitle for the step.
final
- title → String
-
The title of the step.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this DynamicStep instance to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited