DynamicFormTheme class
Theme configuration for customizing the appearance of DynamicForm.
Constructors
- DynamicFormTheme({InputDecoration? inputDecoration, EdgeInsetsGeometry? fieldPadding, TextStyle? labelStyle, TextStyle? hintStyle, Color? errorColor, Widget? loader})
-
Creates a new DynamicFormTheme instance.
const
Properties
- errorColor → Color?
-
The color used for displaying validation errors.
final
- fieldPadding → EdgeInsetsGeometry?
-
The padding around each form field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintStyle → TextStyle?
-
The text style for field hint text.
final
- inputDecoration → InputDecoration?
-
The default InputDecoration to apply to all input fields in the form.
final
- labelStyle → TextStyle?
-
The text style for field labels.
final
- loader → Widget?
-
A custom widget to display as a loader (e.g., during async operations).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveDecoration(
BuildContext context, {FieldDecorationOverride? override, Widget? prefix, Widget? suffix}) → InputDecoration - Merges properties with the default InputDecoration.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited